==> qore-1.14.2.tar.bz2: qore-1.14.2/docs/modules/ConnectionProvider/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore ConnectionProvider Module Reference", "index.html", [
    [ "ConnectionProvider Module", "index.html", [
      [ "ConnectionProvider Module Introduction", "index.html#connectionproviderintro", [
        [ "Connection Provider Modules", "index.html#connectionprovider_modules", null ]
      ] ],
      [ "Release Notes", "index.html#connectionproviderrelnotes", [
        [ "ConnectionProvider 1.8", "index.html#connectionprovider_1_8", null ],
        [ "ConnectionProvider 1.7.4", "index.html#connectionprovider_1_7_4", null ],
        [ "ConnectionProvider 1.7.3", "index.html#connectionprovider_1_7_3", null ],
        [ "ConnectionProvider 1.7.2", "index.html#connectionprovider_1_7_2", null ],
        [ "ConnectionProvider 1.7.1", "index.html#connectionprovider_1_7_1", null ],
        [ "ConnectionProvider 1.7", "index.html#connectionprovider_1_7", null ],
        [ "ConnectionProvider 1.6", "index.html#connectionprovider_1_6", null ],
        [ "ConnectionProvider 1.5", "index.html#connectionprovider_1_5", null ],
        [ "ConnectionProvider 1.4.1", "index.html#connectionprovider_1_4_1", null ],
        [ "ConnectionProvider 1.4", "index.html#connectionprovider_1_4", null ],
        [ "ConnectionProvider 1.3", "index.html#connectionprovider_1_3", null ],
        [ "ConnectionProvider 1.2.1", "index.html#connectionprovider_1_2_1", null ],
        [ "ConnectionProvider 1.2", "index.html#connectionprovider_1_2", null ],
        [ "ConnectionProvider 1.1", "index.html#connectionprovider_1_1", null ],
        [ "ConnectionProvider 1.0.1", "index.html#connectionprovider_1_0_1", null ],
        [ "ConnectionProvider 1.0", "index.html#connectionprovider_1_0", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"class_connection_provider_1_1_polling_connection_monitor.html#a66e90dfbd114ae2b150c5dada410d642"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-1.17.0.tar.bz2: qore-1.17.0/docs/modules/ConnectionProvider/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore ConnectionProvider Module Reference", "index.html", [
    [ "ConnectionProvider Module", "index.html", "index" ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"class_connection_provider_1_1_polling_connection_monitor.html#a631edacb27005ceecc176f59bfe95d74"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
